%bcond_without qt

Summary:	Linux WPA Supplicant (IEEE 802.1X, WPA, WPA2, RSN, IEEE 802.11i)
Name:		wpa_supplicant
Version:	2.9
%define subrel	1
Release:	%mkrel 1
License:	GPLv2+
Group:		Communications/Mobile
URL:		http://hostap.epitest.fi/wpa_supplicant/
Source0:	http://hostap.epitest.fi/releases/wpa_supplicant-%{version}.tar.gz
Source1:	wpa_supplicant.service
Source2:	wpa_supplicant.sysconfig
Source3:	wpa_supplicant.logrotate
Source4:	wpa_supplicant.tmpfiles
Patch10:	wpa_supplicant-2.9-mga-defconfig.patch
Patch11:	wpa_supplicant-1.0-mga-dbus-service-file-args.patch

# fedora patches
# quiet an annoying and frequent syslog message
Patch13:	wpa_supplicant-2.2-quiet-scan-results-message.patch
# distro specific customization for Qt4 build tools, not suitable for upstream
Patch16:	wpa_supplicant-gui-qt4.patch

BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(libpcsclite)
BuildRequires:	readline-devel
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	doxygen
%if %{with qt}
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Widgets)
%endif
BuildRequires:	libnl3-devel
Requires(post):	systemd >= %{systemd_required_version}

%description
wpa_supplicant is a WPA Supplicant for Linux, BSD and Windows with
support for WPA and WPA2 (IEEE 802.11i / RSN). Supplicant is the IEEE
802.1X/WPA component that is used in the client stations. It
implements key negotiation with a WPA Authenticator and it controls
the roaming and IEEE 802.11 authentication/association of the wlan
driver.

wpa_supplicant is designed to be a "daemon" program that runs in the
background and acts as the backend component controlling the wireless
connection. wpa_supplicant supports separate frontend programs and an
example text-based frontend, wpa_cli, is included with wpa_supplicant.

Supported WPA/IEEE 802.11i features:
    * WPA-PSK ("WPA-Personal")
    * WPA with EAP (e.g., with RADIUS authentication server)
      ("WPA-Enterprise")
    * key management for CCMP, TKIP, WEP104, WEP40
    * WPA and full IEEE 802.11i/RSN/WPA2
    * RSN: PMKSA caching, pre-authentication

See the project web site or the eap_testing.txt file for a complete
list of supported EAP methods (IEEE 802.1X Supplicant), supported
drivers and interoperability testing.

%package gui
Group: System/Networking
Summary: Graphical tool for wpa_supplicant
Obsoletes: wpa_gui
Conflicts: wpa_supplicant < 1.0-3

%description gui
wpa_gui is a QT frontend for wpa_supplicant.
wpa_supplicant is a WPA Supplicant for Linux, BSD and Windows with
support for WPA and WPA2 (IEEE 802.11i / RSN).

%prep
%setup -q
%autopatch -p1

pushd wpa_supplicant
# (blino) comment all "network = { }" blocks
perl -pi -e '$_ = "# $_" if /^\s*network\s*=\s*{/ .. /^\s*}/' wpa_supplicant.conf
cp defconfig .config
popd

%build
%setup_compile_flags

pushd wpa_supplicant
# yes, BINDIR=_sbindir
export BINDIR="%{_sbindir}"
export LIBDIR="%{_libdir}"
%make_build
%make_build eapol_test

%if %{with qt}
pushd wpa_gui-qt4
 %qmake_qt5
 %make_build
popd
%endif

popd

%install
install -D -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
install -D -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
install -D -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -D -m 0644 %{SOURCE4} %{buildroot}%{_tmpfilesdir}/%{name}.conf

pushd wpa_supplicant

# binaries
install -d %{buildroot}%{_sbindir}
install -m 755 wpa_supplicant %{buildroot}/%{_sbindir}
install -m 755 wpa_cli %{buildroot}/%{_sbindir}
install -m 755 wpa_passphrase %{buildroot}/%{_sbindir}
install -m 755 eapol_test %{buildroot}%{_sbindir}

%if %{with qt}
# gui
install -d %{buildroot}%{_bindir}
install -m 755 wpa_gui-qt4/wpa_gui %{buildroot}%{_bindir}
%endif

# config
install -d -m 755 %{buildroot}%{_sysconfdir}
install -m 600 wpa_supplicant.conf %{buildroot}%{_sysconfdir}/wpa_supplicant.conf

# dbus
install -d %{buildroot}%{_sysconfdir}/dbus-1/system.d
install -d %{buildroot}%{_datadir}/dbus-1/system-services
install -m 644 dbus/dbus-wpa_supplicant.conf \
    %{buildroot}%{_sysconfdir}/dbus-1/system.d/wpa_supplicant.conf
install -m 0644 dbus/fi.w1.wpa_supplicant1.service \
     %{buildroot}%{_datadir}/dbus-1/system-services

# man pages
install -d -m 755 %{buildroot}%{_mandir}/man{5,8}
install -m 644 doc/docbook/*.8 %{buildroot}%{_mandir}/man8
install -m 644 doc/docbook/*.5 %{buildroot}%{_mandir}/man5

popd

%post
%_tmpfilescreate %{name}

%files
%doc wpa_supplicant/ChangeLog wpa_supplicant/README wpa_supplicant/eap_testing.txt wpa_supplicant/todo.txt
%doc wpa_supplicant/examples/*.conf
%attr(0600,root,daemon) %config(noreplace) %{_sysconfdir}/wpa_supplicant.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/wpa_supplicant
%config(noreplace) %{_sysconfdir}/sysconfig/wpa_supplicant
%{_unitdir}/wpa_supplicant.service
%{_tmpfilesdir}/wpa_supplicant.conf
%{_sbindir}/wpa_cli
%{_sbindir}/wpa_passphrase
%{_sbindir}/wpa_supplicant
%{_sbindir}/eapol_test
%{_sysconfdir}/dbus-1/system.d/wpa_supplicant.conf
# Uncomment after it is enabled
%{_datadir}/dbus-1/system-services/fi.w1.wpa_supplicant1.service
%{_mandir}/man8/*
%{_mandir}/man5/*

%if %{with qt}
%exclude %{_mandir}/man8/wpa_gui.8.*

%files gui
%{_bindir}/wpa_gui
%{_mandir}/man8/wpa_gui.8.*
%endif



%changelog
* Sun Aug 11 2019 luigiwalser <luigiwalser> 2.9-1.1.mga7
+ Revision: 1428747
- log to syslog and fix service file (from wally)
- rediff patch 10
- 2.9

* Tue Apr 02 2019 umeabot <umeabot> 2.7-2.mga7
+ Revision: 1385246
- Qt5 Rebuild

* Sun Dec 30 2018 wally <wally> 2.7-1.mga7
+ Revision: 1347136
- add patch via Gentoo to fix FTBFS
+ luigiwalser <luigiwalser>
- 2.7
- rediff patch 0
- remove upstream patches

* Sun Sep 23 2018 umeabot <umeabot> 2.6-7.mga7
+ Revision: 1301717
- Mageia 7 Mass Rebuild

* Fri Aug 17 2018 daviddavid <daviddavid> 2.6-6.mga7
+ Revision: 1252198
- add patch to fix CVE-2018-14526 (mga#23412)

* Mon May 14 2018 daviddavid <daviddavid> 2.6-5.mga7
+ Revision: 1229296
- port to Qt5

* Tue Jan 02 2018 wally <wally> 2.6-4.mga7
+ Revision: 1189481
- rebuild for new readline

* Tue Oct 17 2017 tmb <tmb> 2.6-3.mga7
+ Revision: 1172350
- fix CVE-2017-130[77-82, 86-88] (mga#21879)

* Wed Aug 02 2017 guillomovitch <guillomovitch> 2.6-2.mga7
+ Revision: 1134121
- rebuild for latest openssl

* Fri Nov 11 2016 luigiwalser <luigiwalser> 2.6-1.mga6
+ Revision: 1066613
- 2.6
- remove upstream patches
- rediff patch 18

* Wed May 18 2016 luigiwalser <luigiwalser> 2.5-4.mga6
+ Revision: 1016799
- add upstream patches to fix CVE-2016-4476 and CVE-2016-4477

* Thu Mar 03 2016 umeabot <umeabot> 2.5-3.mga6
+ Revision: 984751
- Rebuild for openssl

* Wed Feb 17 2016 umeabot <umeabot> 2.5-2.mga6
+ Revision: 963283
- Mageia 6 Mass Rebuild

* Tue Oct 13 2015 tmb <tmb> 2.5-1.mga6
+ Revision: 890295
- drop merged patches
- update to 2.5 (CVE-2015-414[1-5])

* Sat Jul 25 2015 blino <blino> 2.4-1.mga6
+ Revision: 857276
- sync more patches with Fedora
- add CVE-2015-1863 patch from Fedora
- 2.4
- drop merged/obsolete patches

* Sat Oct 25 2014 tmb <tmb> 2.3-3.mga5
+ Revision: 793294
- dont install wpa_supplicant.service with executable permission

* Wed Oct 15 2014 umeabot <umeabot> 2.3-2.mga5
+ Revision: 749760
- Second Mageia 5 Mass Rebuild

* Thu Oct 09 2014 luigiwalser <luigiwalser> 2.3-1.mga5
+ Revision: 737793
- 2.3
- rediff libnl3 includes patch

* Tue Sep 16 2014 umeabot <umeabot> 2.2-2.mga5
+ Revision: 690370
- Mageia 5 Mass Rebuild

* Thu Jul 24 2014 luigiwalser <luigiwalser> 2.2-1.mga5
+ Revision: 656181
- 2.2
- update service unit file (from omdv)
- fix sysconfig file
- rediff defconfig patch
- rediff quiet-scan-results patch (from omdv)
- rediff generate-libeap-peer patch

* Mon Oct 21 2013 umeabot <umeabot> 2.0-2.mga4
+ Revision: 537432
- Mageia 4 Mass Rebuild

* Thu Sep 26 2013 guillomovitch <guillomovitch> 2.0-1.mga4
+ Revision: 487004
- new version 2.0
- sync patches set with fedora

* Sun Mar 24 2013 colin <colin> 1.1-4.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Tue Jan 22 2013 fwang <fwang> 1.1-3.mga3
+ Revision: 390934
- update rpm group

* Mon Jan 14 2013 umeabot <umeabot> 1.1-2.mga3
+ Revision: 385852
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 luigiwalser <luigiwalser> 1.1-1.mga3
+ Revision: 339779
- 1.1

* Sun Nov 25 2012 colin <colin> 1.0-4.mga3
+ Revision: 321738
- Run systemd-tmpfiles --create on post install
- Fix paths to use /run directly
- Remove duplicate arguments from sysconfig file (also in systemd unit)
- Do not package tmpfiles conf in /etc

* Thu Oct 25 2012 wally <wally> 1.0-3.mga3
+ Revision: 310033
- move wpa_gui man page to gui subpkg

* Sat Oct 20 2012 tmb <tmb> 1.0-2.mga3
+ Revision: 308509
- add /var/run/wpa_supplicant dir as default config expects to find it (S4)
+ malo <malo>
- update RPM group

* Thu Aug 16 2012 guillomovitch <guillomovitch> 1.0-1.mga3
+ Revision: 281472
- fix build with libnl3
- new version
- drop madwifi support, as tagged as deprecated, and unavailable in the distribution anyway
- add systemd service file from fedora

* Mon Mar 19 2012 tmb <tmb> 0.7.3-6.mga2
+ Revision: 224518
- build against libnl3

* Tue Jun 21 2011 mikala <mikala> 0.7.3-5.mga2
+ Revision: 111552
- Add patch5 to pass some arguments to wpa_supplicant when launched in dbus
- enable the new dbus interface in configuration file (needed by nm 0.9)
- sync wpa config build with fedora :
  	- enable more EAP (GSK, GSK_SHA256, FAST, FAX, TNC, IKEV2, PAX, )
  	- enable DRIVER_NL80211
  	- enable PKCS12 support
  	- enable SMARTCARD support
  	- enable WPS support

* Mon Jun 20 2011 mikala <mikala> 0.7.3-4.mga2
+ Revision: 110268
- Install wpa_supplicant1.service

* Mon Jun 20 2011 mikala <mikala> 0.7.3-3.mga2
+ Revision: 110253
- Disable patch1 in order to enable dbus interface (need by nm 0.9)
- Add patch3 from fedora (Send PropertyChanged notificationes when the BSS list changes)
- Add patch4 from fedora (Don't crash trying to pass NULL to dbus)

* Tue Feb 15 2011 tmb <tmb> 0.7.3-2.mga1
+ Revision: 51850
- imported package wpa_supplicant


* Wed Sep 08 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 0.7.3-1mdv2011.0
+ Revision: 576819
- update to new stable release
- patch0: update to new code structure
- patch1: temporary comment out new D-Bus service until enabled

* Mon Aug 30 2010 Funda Wang <fwang@mandriva.org> 0.6.10-5mdv2011.0
+ Revision: 574309
- rebuild

* Mon Apr 12 2010 Guillaume Rousse <guillomovitch@mandriva.org> 0.6.10-4mdv2010.1
+ Revision: 533673
- build eapol_test too

* Mon Apr 05 2010 Eugeni Dodonov <eugeni@mandriva.com> 0.6.10-3mdv2010.1
+ Revision: 531899
- Rebuild for openssl 1.0.0.

* Fri Feb 26 2010 Oden Eriksson <oeriksson@mandriva.com> 0.6.10-2mdv2010.1
+ Revision: 511660
- rebuilt against openssl-0.9.8m

  + Andrey Borzenkov <arvidjaar@mandriva.org>
    - patch0: remove -c option, it is perinterface and ignored here anyway

* Mon Feb 01 2010 Pascal Terjan <pterjan@mandriva.org> 0.6.10-1mdv2010.1
+ Revision: 499264
- Update to 0.6.10

* Thu Oct 22 2009 Thomas Backlund <tmb@mandriva.org> 0.6.9-3mdv2010.0
+ Revision: 458985
- revert NL80211 support (fixes #54734, and probably #54368)

* Thu Oct 01 2009 Thomas Backlund <tmb@mandriva.org> 0.6.9-2mdv2010.0
+ Revision: 451906
- add BR libnl-devel for nl80211 support
- build NL80211 support too

* Tue Jul 14 2009 Thomas Backlund <tmb@mandriva.org> 0.6.9-1mdv2010.0
+ Revision: 395980
- update to 0.6.9

* Fri Mar 06 2009 Jérôme Soyer <saispo@mandriva.org> 0.6.8-1mdv2009.1
+ Revision: 349736
- New upstream release

* Mon Nov 24 2008 Olivier Blin <oblin@mandriva.com> 0.6.6-1mdv2009.1
+ Revision: 306238
- fix path in dbus service file and make it use default config file
- install dbus config files
- enable dbus control interface
- 0.6.6

* Mon Sep 01 2008 Olivier Blin <oblin@mandriva.com> 0.6.4-1mdv2009.0
+ Revision: 278137
- drop merged upstream patches
- 0.6.4

* Thu Aug 07 2008 Olivier Blin <oblin@mandriva.com> 0.6.3-6mdv2009.0
+ Revision: 266296
- build Qt4 version of GUI (instead of Qt3)
- rebuild for latest madwifi-source

  + Oden Eriksson <oeriksson@mandriva.com>
    - rebuild

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

* Thu Apr 03 2008 Olivier Blin <oblin@mandriva.com> 0.6.3-3mdv2008.1
+ Revision: 192034
- support 256-bit long WEP232 keys
- use make macro
- use optflags (thanks Anssi)

* Wed Mar 05 2008 Olivier Blin <oblin@mandriva.com> 0.6.3-2mdv2008.1
+ Revision: 180109
- add missing comment in wpa_supplicant.conf (from git, #38481)

* Sun Mar 02 2008 Olivier Blin <oblin@mandriva.com> 0.6.3-1mdv2008.1
+ Revision: 177777
- fix build of Qt3 GUI
- 0.6.3

* Mon Jan 21 2008 Gustavo De Nardin <gustavodn@mandriva.com> 0.6.1-2mdv2008.1
+ Revision: 155645
- provide manpages
- provide sample configs

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Dec 17 2007 Olivier Blin <oblin@mandriva.com> 0.6.1-1mdv2008.1
+ Revision: 121663
- 0.6.1 (notably fix buffer overflow, #36124)

* Tue Aug 28 2007 Olivier Blin <oblin@mandriva.com> 0.6.0-1mdv2008.0
+ Revision: 72748
- enable ralink and wired drivers
- 0.6.0
- do not package COPYING

  + Herton Ronaldo Krzesinski <herton@mandriva.com.br>
    - updated to version 0.5.8


* Wed Jan 03 2007 Olivier Blin <oblin@mandriva.com> 0.5.7-1mdv2007.0
+ Revision: 103759
- workaround profile scripts not sourced yet in iurt
- 0.5.7
- cosmetics

* Thu Sep 07 2006 Olivier Blin <oblin@mandriva.com> 0.5.5-2mdv2007.0
+ Revision: 60194
- drop internal copy of non-free madwifi source, use free madwifi-source package instead
- Import wpa_supplicant

* Wed Sep 06 2006 Olivier Blin <blino@mandriva.com> 0.5.5-1mdv2007.0
- 0.5.5
- update to madwifi 0.9.2
- split QT GUI in wpa_gui package
  (so that wpa_supplicant doesn't require QT and X11 libs)

* Thu Jun 22 2006 Olivier Blin <oblin@mandriva.com> 0.5.4-1mdv2007.0
- New release 0.5.4

* Sat Apr 29 2006 Olivier Blin <oblin@mandriva.com> 0.5.3-1mdk
- New release 0.5.3

* Mon Mar 20 2006 Olivier Blin <oblin@mandriva.com> 0.5.2-1mdk
- New release 0.5.2

* Mon Jan 30 2006 Olivier Blin <oblin@mandriva.com> 0.5.1-1mdk
- New release 0.5.1

* Mon Dec 19 2005 Olivier Blin <oblin@mandriva.com> 0.5.0-1mdk
- New release 0.5.0

* Sat Dec 03 2005 Andreas Hasenack <andreas@mandriva.com> 0.4.7-3mdk
- rebuilt with pcsc-lite 1.2.9

* Wed Nov 23 2005 Olivier Blin <oblin@mandriva.com> 0.4.7-2mdk
- make the description shorter (by removing EAP methods and drivers list)
- remove mkrel macro definition

* Mon Nov 21 2005 Olivier Blin <oblin@mandriva.com> 0.4.7-1mdk
- New release 0.4.7

* Mon Nov 14 2005 Oden Eriksson <oeriksson@mandriva.com> 0.4.6-2mdk
- rebuilt against openssl-0.9.8a

* Sat Oct 29 2005 Olivier Blin <oblin@mandriva.com> 0.4.6-1mdk
- 0.4.6

* Tue Oct 04 2005 Olivier Blin <oblin@mandriva.com> 0.4.5-1mdk
- 0.4.5
- update madwifi drivers (Source2)

* Tue Aug 23 2005 Olivier Blin <oblin@mandriva.com> 0.4.4-1mdk
- 0.4.4

* Wed Jul 06 2005 Olivier Blin <oblin@mandriva.com> 0.4.3-1mdk
- 0.4.3
- developer.txt isn't in the tarball anymore, see
  http://hostap.epitest.fi/wpa_supplicant/devel/

* Wed Jun 08 2005 Arnaud de Lorbeau <devel@mandriva.com> 0.4.1-2mdk
- build and package wpa_gui
- add EAP-AKA and EAP-PSK in build config file

* Sat May 28 2005 Olivier Blin <oblin@mandriva.com> 0.4.1-1mdk
- 0.4.1
- drop Patch0 (SIOCSIWSCANEXT doesn't belong to latest WE 18 proposal)

* Sat May 21 2005 Olivier Blin <oblin@mandriva.com> 0.3.8-9mdk
- update Summary and Description (Arnaud de Lorbeau)
- package eap_testing.txt

* Fri May 20 2005 Olivier Blin <oblin@mandriva.com> 0.3.8-8mdk
- remove crappy code in patch0

* Sat May 14 2005 Olivier Blin <oblin@mandriva.com> 0.3.8-7mdk
- update Patch0 to set ssid for all wext based drivers
  (SIOCSIWSCANEXT isn't supported yet)

* Tue Apr 19 2005 Olivier Blin <oblin@mandrakesoft.com> 0.3.8-6mdk
- remove init script, use WPA support in the initscripts

* Tue Mar 15 2005 Olivier Blin <oblin@mandrakesoft.com> 0.3.8-5mdk
- Patch0: workaround to have WPA working with ipw and hidden ssid

* Tue Mar 15 2005 Olivier Blin <oblin@mandrakesoft.com> 0.3.8-4mdk
- add madwifi support in init script (Adam Williamson, #14637)

* Wed Mar 09 2005 Olivier Blin <oblin@mandrakesoft.com> 0.3.8-3mdk
- make wpa_supplicant.conf readable by root only

* Thu Feb 24 2005 Olivier Blin <oblin@mandrakesoft.com> 0.3.8-2mdk
- update to madwifi-cvs-snapshot-2005-02-24
- use "./madwifi" folder in wpa-config (do not depend on date)
- comment all "network = { }" blocks in wpa_supplicant.conf
- drop Patch0, merged above
- use %%{_sysconfdir}

* Tue Feb 15 2005 Olivier Blin <oblin@mandrakesoft.com> 0.3.8-1mdk
- 0.3.8
- remove Patch1 (ipw support added upstream)
- merge Patch0 in wpa-config
- use ipw driver for ipw2x00 cards in init script
- build control interface (CONFIG_CTRL_IFACE)
- Patch0: comment FAST and PSK AP in wpa_supplicant.conf
  (experimental and not built-in yet)

* Thu Dec 23 2004 Buchan Milne <bgmilne@linux-mandrake.com> 0.2.5-2mdk
- add ipw2100 patch
- distro-specific release tag
- init script (S3)

* Fri Oct 29 2004 Stefan van der Eijk <stefan@mandrake.org> 0.2.5-1mdk
- 0.2.5

* Tue Sep 14 2004 Arnaud de Lorbeau <adelorbeau@mandrakesoft.com> 0.2.4-1mdk
- clean spec
- 0.2.4

* Wed May 12 2004 Tooru Yoshida <yoshida@embeddedlinux.jp>
- wpa_supplicant 0.2.1

